From ed30c60150ffda0301eb1f8d30c93cac94de41df Mon Sep 17 00:00:00 2001
From: tbrehm <t.brehm@ispconfig.org>
Date: Mon, 25 Jul 2011 10:38:22 -0400
Subject: [PATCH] Fixed some warnings in the installer.
---
interface/web/client/client_list.php | 10 +++++-----
1 files changed, 5 insertions(+), 5 deletions(-)
diff --git a/interface/web/client/client_list.php b/interface/web/client/client_list.php
index 6f5a06f..590da21 100644
--- a/interface/web/client/client_list.php
+++ b/interface/web/client/client_list.php
@@ -12,13 +12,13 @@
* End Form configuration
******************************************/
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],$_SESSION["s"]["module"]["name"])) {
- header("Location: ../index.php");
- exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('client');
$app->uses('listform_actions');
+
+$app->listform_actions->SQLOrderBy = 'ORDER BY company_name, contact_name, client_id';
+$app->listform_actions->SQLExtWhere = "limit_client = 0";
$app->listform_actions->onLoad();
--
Gitblit v1.9.1